/*
 * colors.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains Tool.
 *
 * The FFXI Skillchains Tool is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains Tool is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains Tool; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Handles the color dropdown.
 */

var colors = new Array();

function ColorItem(id, name, foreground, background) {
    this.id = id;
    this.name = name;
    this.foreground = foreground;
    this.background = background;
}

{
    var strings;

    // Grab the string bundle
    var strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].getService(Components.interfaces.nsIStringBundleService);
    strings = strBundleService.createBundle("chrome://skillchains/locale/colors.properties");

    var colorNames = strings.GetStringFromName("colors").split(",");
    
    for (var i in colorNames) {
	try {
	    colors.push(
		new ColorItem(
		    colorNames[i],
		    strings.GetStringFromName(colorNames[i]),
		    strings.GetStringFromName(colorNames[i] + ".fg"),
		    strings.GetStringFromName(colorNames[i] + ".bg")
		)
	    );
	} catch (ex) {
	    dump("Unable to load color definition for " + colorNames[i] + "\n");
	    dump(ex);
	}
    }
}

// Inserts rules into an existing stylesheet to specify the colors
function insertColorStyleRules(cssSheet) {
    for (var c in colors) {
	cssSheet.insertRule(".color-" + colors[c].id + " {" +
	         " color: #" + colors[c].foreground + "; " +
		 " background-color: #" + colors[c].background + "" +
		 "}", cssSheet.cssRules.length);
	cssSheet.insertRule(".color-" + colors[c].id + "[_moz-menuactive=\"true\"] {" +
	         " color: #" + colors[c].background + "; " +
		 " background-color: #" + colors[c].foreground + "" +
		 "}", cssSheet.cssRules.length);
    }
}

// Creates a "<style>" node that contains information for the colors
// loaded in this page
function createColorsStyleSheet() {
    var sheet = document.createElement("style");
    sheet.setAttribute("type", "text/css");
    var rules = "";
    for (var c in colors) {
	rules += ".color-" + colors[c].id + " {\r\n" +
	         "    color: #" + colors[c].foreground + ";\r\n" +
		 "    background-color: #" + colors[c].background + ";\r\n" +
		 "}\r\n";
    }
    sheet.appendChild(document.createTextNode(rules));
    return sheet;
}
